<?php

/**
 * @module          Media Gallery
 * @author          cms-lab
 * @copyright       2018-2018 cms-lab
 * @link            http://www.cms-lab.com
 * @license         custom license: http://cms-lab.com/_documentation/media_gallery/license.php
 * @license_terms   please see license
 *
 */

class media_gallery extends LEPTON_abstract
{
	public $media_entries = array();
	public $media_groups = array();	
	public $current_groups = array();
	public $database = 0;
	public $admin = 0;
	public $addon_color = 'blue';
	public $action = LEPTON_URL.'/modules/media_gallery/';	
	public $action_url = ADMIN_URL . '/admintools/tool.php?tool=media_gallery';	

	public static $instance;

	public function initialize() 
	{
		$this->database = LEPTON_database::getInstance();
		$this->admin = LEPTON_admin::getInstance();		
		$this->init_tool();
	}
	
	public function init_tool( $sToolname = '' )
	{
		
		//get media entries
		$this->media_entries = array();
		$this->database->execute_query(
			"SELECT * FROM ".TABLE_PREFIX."mod_media_gallery " ,
			true,
			$this->media_entries,
			true
		);	
		
		//get groups
		$this->media_groups = array();
		$this->database->execute_query(
			"SELECT * FROM ".TABLE_PREFIX."mod_media_gallery_groups " ,
			true,
			$this->media_groups,
			true
		);	

		// get current groups
		foreach($this->media_groups as $temp_group) {
			$this->current_groups[ $temp_group['group_id'] ] =  $temp_group;
		}
				
	}
	
public function list_media() 
	{
		// data for twig template engine	
		$data = array(
			'oMG'			=> $this,
			'readme_link'	=> 'http://cms-lab.com/_documentation/media_gallery/readme.php',
			'leptoken'		=> get_leptoken()			
			);

		/**	
		 *	get the template-engine.
		 */
		$oTwig = lib_twig_box::getInstance();
		$oTwig->registerModule('media_gallery');
			
		echo $oTwig->render( 
			"@media_gallery/list.lte",	//	template-filename
			$data						//	template-data
		);		
		
	}		
	
public function show_info() 
	{
		// create links
		$support_link = "<a href=\"#\">NO Live-Support / FAQ</a>";	
		$readme_link = "<a href=\"http://cms-lab.com/_documentation/media_gallery/readme.php \" class=\"info\" target=\"_blank\">Readme</a>";	

		// data for twig template engine	
		$data = array(
			'oMG'			=> $this,
			'readme_link'	=> $readme_link,		
			'SUPPORT'		=> $support_link,	
			'image_url'		=> 'http://cms-lab.com/_documentation/media/media_gallery/media_gallery.jpg'
			);

		/**	
		 *	get the template-engine.
		 */
		$oTwig = lib_twig_box::getInstance();
		$oTwig->registerModule('media_gallery');
			
		echo $oTwig->render( 
			"@media_gallery/info.lte",	//	template-filename
			$data						//	template-data
		);		
		
	}

public function edit_groups() 
	{
		// data for twig template engine	
		$data = array(
			'oMG'			=> $this,
			'leptoken'		=> get_leptoken()			
			);

		/**	
		 *	get the template-engine.
		 */
		$oTwig = lib_twig_box::getInstance();
		$oTwig->registerModule('media_gallery');
			
		echo $oTwig->render( 
			"@media_gallery/groups.lte",	//	template-filename
			$data						//	template-data
		);		
		
	}	
	
public function save_group($group_id = 0) 
	{
		
		$request = LEPTON_request::getInstance();	
		
		// update table
		$fields = array (
			'mediagroup'	=> array ('type' => 'str', 'default' => ""),
			'active'		=> array ('type' => 'integer', 'default' => 1)
		);
				
		$all_fields = $request->testPostValues($fields);	
		$table = TABLE_PREFIX.'mod_media_gallery_groups';
		$result = $this->database->build_and_execute( 'UPDATE', $table, $all_fields, 'group_id ='.$_POST['save_group']);	
		
		if($result == false) {
			die (LEPTON_tools::display($this->database->get_error(),'pre','ui red message'));
		}						

		// Check if there is a db error, otherwise say successful
		if($this->database->is_error()) {
			$this->admin->print_error($this->database->get_error(), $this->action_url);
		} else {
			$this->admin->print_success($this->language['record_saved'],  $this->action_url);
		}

		// Print admin footer
		$this->admin->print_footer();		
	}

public function copy_group($group_id = 0) 
	{
		
		$copy = $_POST['mediagroup'];
		$_POST['mediagroup'] = $copy.'- Copy';
		
		$request = LEPTON_request::getInstance();	
		
		// update table
		$fields = array (
			'mediagroup'	=> array ('type' => 'str', 'default' => "Copy"),
			'active'		=> array ('type' => 'integer', 'default' => 1)
		);
				
		$all_fields = $request->testPostValues($fields);	
		$table = TABLE_PREFIX.'mod_media_gallery_groups';
		$result = $this->database->build_and_execute( 'INSERT', $table, $all_fields);	
		
		if($result == false) {
			die (LEPTON_tools::display($this->database->get_error(),'pre','ui red message'));
		}						

		// Check if there is a db error, otherwise say successful
		if($this->database->is_error()) {
			$this->admin->print_error($this->database->get_error(), $this->action_url);
		} else {
			$this->admin->print_success($this->language['record_inserted'],  $this->action_url);
		}

		// Print admin footer
		$this->admin->print_footer();		
	}	

	
public function delete_group($group_id = 0) 
	{
		
		$result = $this->database->simple_query("DELETE FROM ".TABLE_PREFIX."mod_media_gallery_groups WHERE group_id=". $_POST['delete_group']." ");					
		
		if($result == false) {
			die (LEPTON_tools::display($this->database->get_error(),'pre','ui red message'));
		}						

		// Check if there is a db error, otherwise say successful
		if($this->database->is_error()) {
			$this->admin->print_error($this->database->get_error(), $this->action_url);
		} else {
			$this->admin->print_success($this->language['record_deleted'],  $this->action_url);
		}

		// Print admin footer
		$this->admin->print_footer();		
	}	

	
public function edit_media( $media_id = -1) 
	{
		
		if($_POST['edit_media'] == 0) {			
			$current_media = array ();		
		}
		
		if($_POST['edit_media'] > 0) {
		
			$current_media = array();
			$this->database->execute_query(
				"SELECT * FROM ".TABLE_PREFIX."mod_media_gallery WHERE media_id = ".$_POST['edit_media']." " ,
				true,
				$current_media,
				false
			);		
		}
		
		/**	
		 *	get the template-engine.
		 */
		$oTwig = lib_twig_box::getInstance();
		$oTwig->registerModule('media_gallery');
		
		// data for twig template engine	
		$data = array(
			'oMG'			=> $this,
			'current_media'	=> $current_media,
			'leptoken'		=> get_leptoken()			
		);
				
		echo $oTwig->render( 
			"@media_gallery/media.lte",	//	template-filename
			$data						//	template-data
		);		
				
	}

	
public function save_media($media_id = 0) 
	{
		if($_POST['save_media'] == 0 ) {
			$job = 'INSERT';
		}
		if($_POST['save_media'] > 0 ) {
			$job = 'UPDATE';
			$media_id = $_POST['save_media'];
		}
//die (LEPTON_tools::display($_POST,'pre','ui red message'));			
		$request = LEPTON_request::getInstance();	
		
		// update table
	  	$fields = array (
			'filetype'		=> array ('type' => 'str', 'default' => "img"),
			'fileurl'		=> array ('type' => 'str', 'default' => " "),
			'mediagroup'	=> array ('type' => 'integer', 'default' => 1),
			'publisher'		=> array ('type' => 'str', 'default' => " "),
			'title'			=> array ('type' => 'str', 'default' => "Copy"),
			'titledate'		=> array ('type' => 'date', 'default' => date('Y-m-d H:i:s')),
			'titlelink_extern'	=> array ('type' => 'str', 'default' => " "),
			'previewurl'	=> array ('type' => 'str', 'default' => " "),
			'previewtitle'	=> array ('type' => 'str', 'default' => " "),
			'previewalt'	=> array ('type' => 'str', 'default' => " "),
			'medialink'		=> array ('type' => 'str', 'default' => ""),
			'active'		=> array ('type' => 'integer', 'default' => 1)
		);
				
		$all_fields = $request->testPostValues($fields);	
		$table = TABLE_PREFIX.'mod_media_gallery';
	
		if($job == 'INSERT'){
			$result = $this->database->build_and_execute( 'INSERT', $table, $all_fields);	
		} elseif($job == 'UPDATE'){
			$result = $this->database->build_and_execute( 'UPDATE', $table, $all_fields, 'media_id ='.$media_id);				
		}	
		
		if($result == false) {
			die (LEPTON_tools::display($this->database->get_error(),'pre','ui red message'));
		}						

		// Check if there is a db error, otherwise say successful
		if($this->database->is_error()) {
			$this->admin->print_error($this->database->get_error(), $this->action_url);
		} else {
			$this->admin->print_success($this->language['record_saved'],  $this->action_url);
		}

		// Print admin footer
		$this->admin->print_footer();		
	}
	
public function copy_media($media_id = 0) 
	{
		$current_media = array();
		$this->database->execute_query(
			"SELECT * FROM ".TABLE_PREFIX."mod_media_gallery WHERE media_id = ".$_POST['copy_media']." " ,
			true,
			$current_media,
			false
		);		

		foreach($current_media as $key => $temp_media) {
			$_POST[$key] = $temp_media;
		}

		$copy = $_POST['title'];
		$_POST['title'] = $copy.'- Copy';
		
		$request = LEPTON_request::getInstance();	
		
		// update table
	  	$fields = array (
			'filetype'		=> array ('type' => 'str', 'default' => "img"),
			'fileurl'		=> array ('type' => 'str', 'default' => " "),
			'mediagroup'	=> array ('type' => 'integer', 'default' => 1),
			'publisher'		=> array ('type' => 'str', 'default' => " "),
			'title'			=> array ('type' => 'str', 'default' => "Copy"),
			'titledate'		=> array ('type' => 'str', 'default' => NULL),
			'titlelink_extern'	=> array ('type' => 'str', 'default' => " "),
			'previewurl'	=> array ('type' => 'str', 'default' => " "),
			'previewtitle'	=> array ('type' => 'str', 'default' => " "),
			'previewalt'	=> array ('type' => 'str', 'default' => " "),
			'medialink'		=> array ('type' => 'str', 'default' => ""),
			'active'		=> array ('type' => 'integer', 'default' => 1)
		);
				
		$all_fields = $request->testPostValues($fields);	
		$table = TABLE_PREFIX.'mod_media_gallery';
		$result = $this->database->build_and_execute( 'INSERT', $table, $all_fields);	
		
		if($result == false) {
			die (LEPTON_tools::display($this->database->get_error(),'pre','ui red message'));
		}						

		// Check if there is a db error, otherwise say successful
		if($this->database->is_error()) {
			$this->admin->print_error($this->database->get_error(), $this->action_url);
		} else {
			$this->admin->print_success($this->language['record_inserted'],  $this->action_url);
		}

		// Print admin footer
		$this->admin->print_footer();		
	}	

	
public function delete_media($media_id = 0) 
	{
		$result = $this->database->simple_query("DELETE FROM ".TABLE_PREFIX."mod_media_gallery WHERE media_id=". $_POST['delete_media']." ");					
		
		if($result == false) {
			die (LEPTON_tools::display($this->database->get_error(),'pre','ui red message'));
		}						

		// Check if there is a db error, otherwise say successful
		if($this->database->is_error()) {
			$this->admin->print_error($this->database->get_error(), $this->action_url);
		} else {
			$this->admin->print_success($this->language['record_deleted'],  $this->action_url);
		}

		// Print admin footer
		$this->admin->print_footer();		
	}	

	
} // end of class
?>